==> open-xchange-core_7.8.4.orig.tar.bz2: open-xchange-core-7.8.4/com.openexchange.server/src/com/openexchange/mailaccount/internal/MailAccountOAuthAccountReauthorizedListener.java <==
/*
 *
 *    OPEN-XCHANGE legal information
 *
 *    All intellectual property rights in the Software are protected by
 *    international copyright laws.
 *
 *
 *    In some countries OX, OX Open-Xchange, open xchange and OXtender
 *    as well as the corresponding Logos OX Open-Xchange and OX are registered
 *    trademarks of the OX Software GmbH. group of companies.
 *    The use of the Logos is not covered by the GNU General Public License.
 *    Instead, you are allowed to use these Logos according to the terms and
 *    conditions of the Creative Commons License, Version 2.5, Attribution,
 *    Non-commercial, ShareAlike, and the interpretation of the term
 *    Non-commercial applicable to the aforementioned license is published
 *    on the web site http://www.open-xchange.com/EN/legal/index.html.
 *
 *    Please make sure that third-party modules and libraries are used
 *    according to their respective licenses.
 *
 *    Any modifications to this package must retain all copyright notices
 *    of the original copyright holder(s) for the original code used.
 *
 *    After any such modifications, the original and derivative code shall remain
 *    under the copyright of the copyright holder(s) and/or original author(s)per
 *    the Attribution and Assignment Agreement that can be located at
 *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
 *    given Attribution for the derivative code and a license granting use.
 *
 *     Copyright (C) 2016-2020 OX Software GmbH
 *     Mail: info@open-xchange.com
 *
 *
 *     This program is free software; you can redistribute it and/or modify it
 *     under the terms of the GNU General Public License, Version 2 as published
 *     by the Free Software Foundation.
 *
 *     This program is distributed in the hope that it will be useful, but
 *     WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 *     or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
 *     for more details.
 *
 *     You should have received a copy of the GNU General Public License along
 *     with this program; if not, write to the Free Software Foundation, Inc., 59
 *     Temple Place, Suite 330, Boston, MA 02111-1307 USA
 *
 */

package com.openexchange.mailaccount.internal;

import java.sql.Connection;
import java.util.Map;
import com.openexchange.exception.OXException;
import com.openexchange.mailaccount.MailAccount;
import com.openexchange.mailaccount.MailAccountStorageService;
import com.openexchange.oauth.OAuthAccountReauthorizedListener;
import com.openexchange.server.services.ServerServiceRegistry;


/**
 * {@link MailAccountOAuthAccountReauthorizedListener}
 *
 * @author <a href="mailto:thorben.betten@open-xchange.com">Thorben Betten</a>
 * @since v7.8.4
 */
public class MailAccountOAuthAccountReauthorizedListener extends MailAccountOAuthAccountListener implements OAuthAccountReauthorizedListener {

    /**
     * Initializes a new {@link MailAccountOAuthAccountReauthorizedListener}.
     */
    public MailAccountOAuthAccountReauthorizedListener() {
        super();
    }

    @Override
    public void onAfterOAuthAccountReauthorized(int oauthAccountId, Map<String, Object> eventProps, int user, int contextId, Connection con) throws OXException {
        MailAccountStorageService mass = ServerServiceRegistry.getInstance().getService(MailAccountStorageService.class);
        if (null != mass) {
            MailAccount[] userMailAccounts = mass.getUserMailAccounts(user, contextId, con);
            for (MailAccount mailAccount : userMailAccounts) {
                if (false == mailAccount.isDefaultAccount() && false == isUnifiedINBOXAccount(mailAccount)) {
                    enbledMailAccount(mailAccount, oauthAccountId, user, contextId, con, mass);
                }
            }
        }
    }

    private void enbledMailAccount(MailAccount mailAccount, int oauthAccountId, int userId, int contextId, Connection con, MailAccountStorageService mass) throws OXException {
        boolean updated = false;
        if (mailAccount.isMailOAuthAble()) {
            if (mailAccount.getMailOAuthId() == oauthAccountId) {
                mass.enableMailAccount(mailAccount.getId(), userId, contextId, con);
                updated = true;
            }
        }
        if (!updated && mailAccount.isTransportOAuthAble()) {
            if (mailAccount.getTransportOAuthId() == oauthAccountId) {
                mass.enableMailAccount(mailAccount.getId(), userId, contextId, con);
            }
        }
    }

}

==> open-xchange-core_7.10.1.orig.tar.bz2: open-xchange-core-7.10.1/com.openexchange.server/src/com/openexchange/mailaccount/internal/MailAccountOAuthAccountReauthorizedListener.java <==
/*
 *
 *    OPEN-XCHANGE legal information
 *
 *    All intellectual property rights in the Software are protected by
 *    international copyright laws.
 *
 *
 *    In some countries OX, OX Open-Xchange, open xchange and OXtender
 *    as well as the corresponding Logos OX Open-Xchange and OX are registered
 *    trademarks of the OX Software GmbH. group of companies.
 *    The use of the Logos is not covered by the GNU General Public License.
 *    Instead, you are allowed to use these Logos according to the terms and
 *    conditions of the Creative Commons License, Version 2.5, Attribution,
 *    Non-commercial, ShareAlike, and the interpretation of the term
 *    Non-commercial applicable to the aforementioned license is published
 *    on the web site http://www.open-xchange.com/EN/legal/index.html.
 *
 *    Please make sure that third-party modules and libraries are used
 *    according to their respective licenses.
 *
 *    Any modifications to this package must retain all copyright notices
 *    of the original copyright holder(s) for the original code used.
 *
 *    After any such modifications, the original and derivative code shall remain
 *    under the copyright of the copyright holder(s) and/or original author(s)per
 *    the Attribution and Assignment Agreement that can be located at
 *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
 *    given Attribution for the derivative code and a license granting use.
 *
 *     Copyright (C) 2016-2020 OX Software GmbH
 *     Mail: info@open-xchange.com
 *
 *
 *     This program is free software; you can redistribute it and/or modify it
 *     under the terms of the GNU General Public License, Version 2 as published
 *     by the Free Software Foundation.
 *
 *     This program is distributed in the hope that it will be useful, but
 *     WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 *     or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
 *     for more details.
 *
 *     You should have received a copy of the GNU General Public License along
 *     with this program; if not, write to the Free Software Foundation, Inc., 59
 *     Temple Place, Suite 330, Boston, MA 02111-1307 USA
 *
 */

package com.openexchange.mailaccount.internal;

import java.sql.Connection;
import java.util.Map;
import com.openexchange.exception.OXException;
import com.openexchange.mailaccount.MailAccount;
import com.openexchange.mailaccount.MailAccountStorageService;
import com.openexchange.oauth.OAuthAccountReauthorizedListener;
import com.openexchange.server.services.ServerServiceRegistry;


/**
 * {@link MailAccountOAuthAccountReauthorizedListener}
 *
 * @author <a href="mailto:thorben.betten@open-xchange.com">Thorben Betten</a>
 * @since v7.8.4
 */
public class MailAccountOAuthAccountReauthorizedListener extends MailAccountOAuthAccountListener implements OAuthAccountReauthorizedListener {

    /**
     * Initializes a new {@link MailAccountOAuthAccountReauthorizedListener}.
     */
    public MailAccountOAuthAccountReauthorizedListener() {
        super();
    }

    @Override
    public void onAfterOAuthAccountReauthorized(int oauthAccountId, Map<String, Object> eventProps, int user, int contextId, Connection con) throws OXException {
        MailAccountStorageService mass = ServerServiceRegistry.getInstance().getService(MailAccountStorageService.class);
        if (null != mass) {
            MailAccount[] userMailAccounts = mass.getUserMailAccounts(user, contextId, con);
            for (MailAccount mailAccount : userMailAccounts) {
                if (false == mailAccount.isDefaultAccount() && false == isUnifiedINBOXAccount(mailAccount) && mailAccount.getMailOAuthId() == oauthAccountId) {
                    enbledMailAccount(mailAccount, oauthAccountId, user, contextId, con, mass);
                }
            }
        }
    }

    private void enbledMailAccount(MailAccount mailAccount, int oauthAccountId, int userId, int contextId, Connection con, MailAccountStorageService mass) throws OXException {
        boolean updated = false;
        if (mailAccount.isMailOAuthAble()) {
            if (mailAccount.getMailOAuthId() == oauthAccountId) {
                mass.enableMailAccount(mailAccount.getId(), userId, contextId, con);
                updated = true;
            }
        }
        if (!updated && mailAccount.isTransportOAuthAble()) {
            if (mailAccount.getTransportOAuthId() == oauthAccountId) {
                mass.enableMailAccount(mailAccount.getId(), userId, contextId, con);
            }
        }
    }

}
